@@ -313,7 +313,7 @@ class QalxAdapter(object):
         if many is False:
 
             # We are expecting only a single entity.
-            entities = entities["data"]
+            entities = entities.data
             if len(entities) > 1:
                 entities_str = "\n".join([str(q) for q in entities])
                 raise QalxMultipleEntityReturned(
@@ -362,7 +362,7 @@ class QalxAdapter(object):
         :param entity: An instance of `self.entity_class`
         :return: A refreshed instance of `self.entity_class`
         """
-        return self.get(entity["guid"], *args, **kwargs)
+        return self.get(entity.guid, *args, **kwargs)
 
     def save(self, entity, *args, **kwargs):
         """
@@ -476,7 +476,7 @@ class QalxUnpackableAdapter(QalxAdapter):
                 )
             for future in concurrent.futures.as_completed(_futures):
                 try:
-                    unpacked_entities += future.result()["data"]
+                    unpacked_entities += future.result().data
                 except QalxAPIResponseError as exc:
                     self.raise_api_response_error(exc)
         return unpacked_entities
@@ -554,7 +554,7 @@ class QalxUnpackableAdapter(QalxAdapter):
             # Iterate through the key/values on the children of this entity
             # and update the appropriate key from the fully_unpacked_entities.
             for child_entity in fully_unpacked_entities:
-                if child_guid == child_entity["guid"]:
+                if child_guid == child_entity.guid:
                     to_return[key] = child_entity
         return to_return
 
@@ -583,9 +583,7 @@ class QalxUnpackableAdapter(QalxAdapter):
         :param kwargs: The kwargs sent to the `add` method
         :return: kwargs with packed kids
         """
-        kids = {
-            key: str(kid["guid"]) for key, kid in kwargs[self.kids].items()
-        }  # noqa
+        kids = {key: str(kid.guid) for key, kid in kwargs[self.kids].items()}
         kwargs[self.kids] = kids
         return kwargs
 
@@ -750,9 +748,7 @@ class QalxSignalAdapter(QalxAdapter):
         Gets just the `signal` field from the entity and then parses that
         into the `signal_class`
         """
-        entity = self.get(
-            guid=entity["guid"], fields="signal", *args, **kwargs
-        )  # noqa
+        entity = self.get(guid=entity["guid"], fields="signal", *args, **kwargs)
         signal = self.signal_class(entity)
         return signal
 
