@@ -310,7 +310,7 @@ class QalxBlueprint(QalxUnpackableAdapter, QalxNamedEntityAdapter):
             for child_entity in unpacked_entities:
                 if (
                     value.get("enum")
-                    and value.get("enum")[0] == child_entity["name"]
+                    and value.get("enum")[0] == child_entity.name
                 ):
-                    kids_properties[key] = child_entity["schema"]
+                    kids_properties[key] = child_entity.schema
         return kids_properties
