@@ -1,13 +1,19 @@
 import os
 import types
 from itertools import zip_longest
+from time import sleep
 
 import requests
 from addict import Dict
 
 from pyqalx.core.encryption import QalxEncrypt
 
-from pyqalx.core.errors import QalxAPIResponseError, QalxError, QalxQueueError
+from pyqalx.core.errors import (
+    QalxAPIResponseError,
+    QalxError,
+    QalxQueueError,
+    QalxFileRetrievalError,
+)
 
 
 class QalxAddict(Dict):
@@ -280,16 +286,15 @@ class QalxFileEntity(QalxEntity):
         reserved_keys += ["_key_file", "_file_bytes"]
         return reserved_keys
 
-    def read_file(self):
+    def read_file(self, retry=True):
         """
         If this Item contains a file, will read the file data and cache it
         against the Item.
 
-        :param key_file:    The path to the encryption key to be used for
-                            decrypting the file data. If it is not provided
-                            and the data was encrypted, the data will be read
-                            in the encrypted format
-        :type key_file: str
+        :param retry:   Should the download retry if there is a problem
+                        getting the file from S3?  By default, the download
+                        will retry once
+        :type retry: bool
         :return:    The content of the URL as a bytes object.  Accessible from
                     the `_file_bytes` attribute
         :raises QalxError:
@@ -299,6 +304,7 @@ class QalxFileEntity(QalxEntity):
         else:
             response = requests.get(url=self[self._file_key]["url"])
             if response.ok:
+                # File retrieved Ok
                 file_bytes = response.content
                 if (
                     self[self._file_key].get("keyfile") is not None
@@ -309,7 +315,15 @@ class QalxFileEntity(QalxEntity):
                 self._file_bytes = file_bytes
                 return self._file_bytes
             else:
-                raise QalxError(
+                # Problem getting the file - possibly S3 has had a minor
+                # hiccough. This is probably only temporary so wait a couple of
+                # seconds and try again (ensuring that we raise an exception if
+                # the download fails a second time)
+                if retry:
+                    sleep(2)
+                    return self.read_file(retry=False)
+                # If we're not retrying then raise an error with the error message
+                raise QalxFileRetrievalError(
                     "Error with file retrieval: \n\n" + response.text
                 )
 
