@@ -30,9 +30,10 @@ def _msg_user(
     colorama.init()
     bright = Style.BRIGHT
     normal = Style.NORMAL
-    if level == logging.ERROR:
+    if level == logging.ERROR or fore == Fore.RED:
+        # Ensure any errors - or those with a RED foreground are displayed
+        # using a BRIGHT style
         fore = Fore.RED
-        # Make sure the errors pop!
         normal = Style.BRIGHT
     now = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
     title = f"[{now}] {title}"
