@@ -117,7 +117,7 @@ class AWSStack:
         bootstrap_script = (
             f"sudo -u ec2-user bash -c "
             f"'. /home/ec2-user/pyqalx/pyqalx_factory_bootstrap.sh "
-            f"--factory_guid {self.factory_entity['guid']} "
+            f"--factory_guid {self.factory_entity.guid} "
             f"--sector_name {sector_name} "
             f"--profile_name {sector['profile_name']} "
             f"--region_name {sector['region_name']} "
@@ -173,7 +173,7 @@ class AWSStack:
         )
         bootstrap_script = (
             f"{cmd} "
-            f"--factory_guid {self.factory_entity['guid']} "
+            f"--factory_guid {self.factory_entity.guid} "
             f"--sector_name {sector_name} "
             f"--profile_name {sector['profile_name']} "
             f"--region_name {sector['region_name']} "
@@ -184,7 +184,6 @@ class AWSStack:
             Join(
                 "",
                 [
-                    # TODO: Figure out how to handle this with updates
                     "<script>",
                     "\n",
                     bootstrap_script,
